@@ -4,21 +4,21 @@
 (defparameter *autoconf-prefix* "/usr")
 (defparameter *autoconf-exec_prefix* "/usr")
 (defparameter *autoconf-package* "maxima")
-(defparameter *autoconf-version* "5.48.1")
+(defparameter *autoconf-version* "5.49.0")
 (defparameter *autoconf-libdir* "/usr/lib")
 (defparameter *autoconf-libexecdir* "/usr/lib")
 (defparameter *autoconf-datadir* "/usr/share")
 (defparameter *autoconf-infodir* "/usr/share/info")
-(defparameter *autoconf-host* "x86_64-pc-linux-gnu")
+(defparameter *autoconf-host* "x86_64-unknown-linux-gnu")
 ;; This variable is kept for backwards compatibility reasons:
 ;; We seem to be in the fortunate position that we sometimes need to check for windows.
 ;; But at least until dec 2015 we didn't need to check for a specific windows flavour.
 (defparameter *autoconf-win32* "false")
 (defparameter *autoconf-windows* "false")
-(defparameter *autoconf-ld-flags* "-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto")
+(defparameter *autoconf-ld-flags* "-Wl,-O1,--sort-common,--as-needed,-z,relro")
 
 ;; This will be T if this was a lisp-only build
 (defparameter *autoconf-lisp-only-build* (eq t 'nil))
  
-(defparameter *maxima-source-root* "/build/maxima/src/maxima")
+(defparameter *maxima-source-root* "/buildsys/main/maxima/src/maxima-5.49.0")
 (defparameter *maxima-default-layout-autotools* "true")
